@@ -18,7 +18,12 @@ class Ascentlint(Edatool):
 
 Ascent Lint performs static source code analysis on HDL code and checks for
 common coding errors or coding style violations.
-"""}
+""",
+                    'lists' : [
+                        {'name' : 'ascentlint_options',
+                         'type' : 'String',
+                         'desc' : 'Additional run options for ascentlint'}
+                    ]}
 
     def configure_main(self):
         (src_files, incdirs) = self._get_fileset_files(force_slash=True)
@@ -31,6 +36,7 @@ common coding errors or coding style violations.
 
         template_vars = {
             'name'             : self.name,
+            'ascentlint_options' : ' '.join(self.tool_options.get('ascentlint_options', [])),
             'tcl_source_files' : tcl_source_files,
             'waiver_files'     : waiver_files,
             'toplevel'         : self.toplevel,
